Renku Command Line — Renku 0.1.0.dev20180518 documentation

Join us on GitHub

# Renku Command Line

The base command for interacting with the Renku platform.

## `renku` (base command)

To list the available commands, either run `renku` with no parameters or execute `renku help`:

    $ renku help
    Usage: renku [OPTIONS] COMMAND [ARGS]...

    Check common Renku commands used in various situations.

    Options:
      --version            Print version number.
      --config PATH        Location of client config files.
      --config-path        Print application config path.
      --path <path>        Location of a Renku repository.  [default: .]
      --renku-home <path>  Location of Renku directory.  [default: .renku]
      -h, --help           Show this message and exit.

    Commands:
      # [...]

### Configuration files

Depending on your system, you may find the configuration files used by Renku command line in a different folder. By default, the following rules are used:

MacOS:
  `~/Library/Application Support/Renku`
Unix:
  `~/.config/renku`
Windows:
  `C:\Users\<user>\AppData\Roaming\Renku`

If in doubt where to look for the configuration file, you can display its path by running `renku --config-path`.

You can specify a different location via the `RENKU_CONFIG` environment variable or the `--config` command line option. If both are specified, then the `--config` option value is used. For example:

    $ renku --config ~/renku/config/ init

instructs Renku to store the configuration files in your `~/renku/config/` directory when running the `init` command.

## `renku init`

Create an empty Renku project or reinitialize an existing one.

### Starting a Renku project

If you have an existing directory which you want to turn into a Renku project, you can type:

    $ cd ~/my_project
    $ renku init

or:

    $ renku init ~/my_project

This creates a new subdirectory named `.renku` that contains all the necessary files for managing the project configuration.

## `renku datasets`

Work with datasets in the current repository.

### Manipulating datasets

Creating an empty dataset inside a Renku project:

    $ renku dataset create my-dataset

Adding data to the dataset:

    $ renku dataset add my-dataset http://data-url

This will copy the contents of `data-url` to the dataset and add it to the dataset metadata.

## `renku run`

Track provenance of data created by executing programs.

## `renku log`

Show provenance of data created by executing programs.

## `renku workflow`

Workflow operations.